from .errors.error import Error
from .ui.views.view import View
from .helpers.helper import Helper
from .helpers.logger import logger
from .helpers.builder import Builder
from .models.domains.omen import Omen
from .ui.emitters.emitter import Emitter
from .helpers.assembler import Assembler
from .helpers.singleton import Singleton
from .models.domains.domain import Domain
from .models.mappers.mapper import Mapper
from .models.services.service import Service
from .models.domains.database import Database
from .helpers.decorators import login_required
from .ui.controllers.controller import Controller
from .models.services.omen_service import OmenService
from .ui.controllers.omen_controller import OmenController
from .models.services.database_service import DatabaseService
from .ui.controllers.database_controller import DatabaseController
from .helpers.cells import (Cell, ViewCell, ConfigCell, InjectionCell, MapperCell, EmitterCell)
from .helpers.constants import (
    Json, Path, HttpMethod, ConfigLoadType, HTTP_METHODS, CONFIG_LOAD_TYPES
)


from distutils.core import setup


setup(
    name="omen-web",
    packages=["omen"],
    version="0.1.5",
    license="MIT",
    description="Upgraded layer over Flask.",
    author = "Alexander Ryzhov",
    author_email = "thed4rkof@gmail.com",
    url = "https://github.com/ryzhovalex/omen",
    download_url = "https://github.com/ryzhovalex/omen/archive/refs/tags/0.1.5.tar.gz",
    keywords = ["flask+", "web-framework", "flask", "flask-template"],
    install_requires=[
        "flask",
        "requests",
        "turbo-flask",
        "flask-migrate",
        "loguru",
        "pytest",
    ],
    classifiers=[
        "Development Status :: 1 - Planning",

        "Intended Audience :: Developers",
        "Topic :: Software Development :: Build Tools",

        "License :: OSI Approved :: MIT License",

        "Programming Language :: Python :: 3.9",
    ],
)